[ [Back to index](README.md) ]

<!--
This file is generated automatically - don't edit!
-->

This is an automatically generated list of portable and reusable automation recipes (CM scripts)
with a [human-friendly interface (CM)](https://github.com/mlcommons/ck) 
to run a growing number of ad-hoc MLPerf, MLOps, and DevOps scripts
from [MLCommons projects](https://github.com/mlcommons/cm4mlops/tree/main/script)
and [research papers](https://www.youtube.com/watch?v=7zpeIVwICa4) 
in a unified way on any operating system with any software and hardware
natively or inside containers.

Click on any automation recipe below to learn how to run and reuse it 
via CM command line, Python API or GUI.

CM scripts can easily chained together into automation workflows using `deps` and `tags` keys
while automatically updating all environment variables and paths 
for a given task and platform [using simple JSON or YAML](https://github.com/mlcommons/ck/blob/master/cm-mlops/script/app-image-classification-onnx-py/_cm.yaml).


*Note that CM is a community project being developed and extended by [MLCommons members and individual contributors](../CONTRIBUTING.md) -
 you can find source code of CM scripts maintained by MLCommons [here](../cm-mlops/script).
 Please join [Discord server](https://discord.gg/JjWNWXKxwT) to participate in collaborative developments or provide your feedback.*


# License

[Apache 2.0](LICENSE.md)


# Copyright

2022-2024 [MLCommons](https://mlcommons.org)





# List of CM scripts by categories

{{CM_TOC_CATEGORIES}}

{{CM_TOC2}}

# List of all sorted CM scripts 

{{CM_TOC}}


{{CM_MAIN}}
